textmining.tmTransformer.TsujiiXPathTransformer

|  | ## Cheshire3 Object Model: Class TsujiiXPathTransformer

Package textmining :: Module tmTransformer :: Class TsujiiXPathTransformer

## Class TsujiiXPathTransformer
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
      baseObjects.Transformer --+
                                |
                   PosTransformer --+
                                    |
            TsujiiC3.TsujiiObject --+
                                    |
                                   TsujiiXPathTransformer

Instance Methods

_handleConfigNode(self, session, node)
__init__(self, session, node, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
process_record(self, session, rec) Take a Record, transform it and return a new Document object.
Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__` Inherited from `TsujiiC3.TsujiiObject`: `tag`, `toxml`

Class Variables

copyElems |
tagElems |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__` Inherited from `TsujiiC3.TsujiiObject`: `inh`, `outh`, `tokenizer`

Method Details

### _handleConfigNode(self, session, node) | source code
Overrides: configParser.C3Object._handleConfigNode

### __init__(self, session, node, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### process_record(self, session, rec) | source code
Take a Record, transform it and return a new Document object. Overrides: baseObjects.Transformer.process_record (inherited documentation)

Class Variable Details

    ### copyElems Value:
        []

    ### tagElems Value:
        []